@@ -468,6 +468,9 @@ sub render
 {
         my ($self, $cr, $settings, $index, $total) = @_;
 
+        if ($settings->{daynum_size} < 0) {
+                $settings->{daynum_size} = 14;
+        }
         if ($settings->{svg} || $settings->{eps}) {
                 if ($index > 1) {
                         if ($index == 2) {
@@ -628,7 +631,7 @@ sub col_box_coordinates
                 $settings->{margin_left} + $cell * $col,
                 $so_far,
                 $settings->{margin_left} + $cell * ($col + 1),
-                $so_far + $height + $settings->{border_size},
+                $so_far + $height + 2* $settings->{border_size},
             );
 }
 
@@ -663,7 +666,7 @@ sub draw_day
                         $cr->set_source_rgb($shade->{r} / 255,
                                             $shade->{g} / 255,
                                             $shade->{b} / 255);
-                        $cr->rectangle($x1, $y1, $x2 - $x1, $y2 - $y1 + $settings->{border_size});
+                        $cr->rectangle($x1, $y1, $x2 - $x1, $y2 - $y1);
                         $cr->fill();
                         $cr->restore;
                 }
@@ -1111,6 +1114,9 @@ Remind::PDF::Weekly - render a weekly calendar
 sub render
 {
         my ($self, $cr, $settings, $index, $total) = @_;
+        if ($settings->{daynum_size} < 0) {
+                $settings->{daynum_size} = 10;
+        }
         if ($settings->{svg} || $settings->{eps}) {
                 if ($index > $settings->{weeks_per_page}) {
                         if ($index == $settings->{weeks_per_page}+1) {
@@ -1130,7 +1136,7 @@ sub render
                 }
         }
 
-        $settings->{numbers_on_left} = 1;
+        $settings->{numbers_on_left} = 0;
         # Set up bounding box
         if ($settings->{weeks_per_page} == 1) {
                 $self->{bounding_box} = [
@@ -1139,22 +1145,16 @@ sub render
                         $settings->{width} - $settings->{margin_right},
                         $settings->{height} - $settings->{margin_bottom}]
         } else {
+                my $gap = $settings->{margin_top} * 0.5;
                 my $total_height = $settings->{height} - $settings->{margin_top} - $settings->{margin_bottom};
-                my $week_height = $total_height / $settings->{weeks_per_page};
-                my $top_offset = (($index-1) % $settings->{weeks_per_page}) * $week_height;
+                my $week_height = ($total_height - $gap * ($settings->{weeks_per_page}-1)) / $settings->{weeks_per_page};
+                my $top_offset = ((($index-1) % $settings->{weeks_per_page}) * $week_height) + (($index-1) % $settings->{weeks_per_page})  * $gap;
                 my $bot_offset = $top_offset + $week_height;
-                $self->{bounding_box} = 
-                    $self->{bounding_box} = [
-                            $settings->{margin_left},
-                            $settings->{margin_top} + $top_offset,
-                            $settings->{width} - $settings->{margin_right},
-                            $settings->{margin_top} + $bot_offset];
-                if ($index != 1) {
-                        $self->{bounding_box}[1] += 0.25 * $settings->{margin_top};
-                }
-                if ($index != $settings->{weeks_per_page}) {
-                    $self->{bounding_box}[3] -= 0.25 * $settings->{margin_top};
-                }
+                $self->{bounding_box} = [
+                        $settings->{margin_left},
+                        $settings->{margin_top} + $top_offset,
+                        $settings->{width} - $settings->{margin_right},
+                        $settings->{margin_top} + $bot_offset];
         }
         $self->draw_headings($cr, $settings);
         for (my $i=0; $i<7; $i++) {
@@ -1262,7 +1262,13 @@ sub draw_entries
         $layout->set_font_description($desc);
         my ($wid, $h) = $layout->get_pixel_size();
 
-        my $so_far = $box->[1] + $h + $settings->{border_size};
+        my $so_far = $box->[1] + $settings->{border_size};
+        foreach my $entry (@{$self->{entries}->[$i]}) {
+                if ($entry->isa('Remind::PDF::Entry::moon')) {
+                        $so_far = $box->[1] + $h + $settings->{border_size};
+                        last;
+                }
+        }
 
         my $box_height = $box->[3] - $box->[1];
         my $done = 0;
