@@ -2078,6 +2078,11 @@ static int DoCalRem(ParsePtr p, int col)
             FreeTrig(&trig);
             return OK;
         }
+        if (dse < 0 && !ParseUntriggered) {
+            /* Expired */
+            FreeTrig(&trig);
+            return OK;
+        }
     } else {
         /* Calculate the trigger date */
         EnterTimezone(trig.tz);
@@ -2090,6 +2095,11 @@ static int DoCalRem(ParsePtr p, int col)
             FreeTrig(&trig);
             return r;
         }
+        if (dse < 0 && !ParseUntriggered) {
+            /* Expired */
+            FreeTrig(&trig);
+            return OK;
+        }
     }
 
     /* Adjust trigger date/time to time zone */
