@@ -31,6 +31,39 @@
 
 #define SHIP_OUT(s) if(DBufPuts(dbuf, s) != OK) return E_NO_MEM
 
+static char const *
+get_function_override(int c, int addx)
+{
+    static char func[32];
+
+    if (isalnum(c) || c == '_') {
+        if (addx) {
+            snprintf(func, sizeof(func), "subst_%cx", tolower(c));
+        } else {
+            snprintf(func, sizeof(func), "subst_%c", tolower(c));
+        }
+        return func;
+    }
+    if (addx) {
+        switch(c) {
+        case ':': return "subst_colonx";
+        case '!': return "subst_bangx";
+        case '?': return "subst_questionx";
+        case '@': return "subst_atx";
+        case '#': return "subst_hashx";
+        }
+    } else {
+        switch(c) {
+        case ':': return "subst_colon";
+        case '!': return "subst_bang";
+        case '?': return "subst_question";
+        case '@': return "subst_at";
+        case '#': return "subst_hash";
+        }
+    }
+    return NULL;
+}
+
 static int
 check_subst_args(UserFunc *f, int n)
 {
@@ -40,8 +73,10 @@ check_subst_args(UserFunc *f, int n)
     if (f->nargs == n) {
         return 1;
     }
-    Wprint(tr("Function `%s' defined at %s(%s) should take %d argument%s, but actually takes %d"),
-           f->name, f->filename, line_range(f->lineno_start, f->lineno), n, (n == 1 ? "" : "s"), f->nargs);
+    if (warning_level("05.00.03")) {
+        Wprint(tr("Function `%s' defined at %s(%s) should take %d argument%s, but actually takes %d"),
+               f->name, f->filename, line_range(f->lineno_start, f->lineno), n, (n == 1 ? "" : "s"), f->nargs);
+    }
     return 0;
 }
 /***************************************************************/
@@ -57,6 +92,8 @@ check_subst_args(UserFunc *f, int n)
 int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int dse, int mode)
 {
     int diff = dse - DSEToday;
+    int rdiff = dse - RealToday;
+    int bangdiff = diff;
     int curtime = MinutesPastMidnight(0);
     int err, done;
     int c;
@@ -67,12 +104,13 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
     char const *pm, *cpm;
     int tdiff, adiff, mdiff, hdiff;
     char const *mplu, *hplu, *when, *plu;
+    char const *is, *was;
     int has_quote = 0;
     char *ss;
     char const *expr;
     char *os;
     char s[256];
-    char uf[32];
+    char const *substname;
     char mypm[64];
     char mycpm[64];
     char myplu[64];
@@ -98,7 +136,8 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
     mplu = (mdiff == 1 ? "" : DynamicMplu);
     hplu = (hdiff == 1 ? "" : DynamicHplu);
 
-    when = (tdiff < 0) ? tr("ago") : tr("from now");
+    when = (tdiff < 0) ? tr("ago") :
+                         tr("from now");
 
     h = tim / 60;
     min = tim % 60;
@@ -108,7 +147,7 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
     if (func && check_subst_args(func, 1)) {
         snprintf(s, sizeof(s), "subst_ampm(%d)", h);
         expr = (char const *) s;
-        r = EvalExpr(&expr, &v, NULL);
+        r = EvalExprRunDisabled(&expr, &v, NULL);
         if (r == OK) {
             if (!DoCoerce(STR_TYPE, &v)) {
                 snprintf(mypm, sizeof(mypm), "%s", v.v.str);
@@ -122,7 +161,8 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
         }
     }
     if (r != OK) {
-        pm = (h < 12) ? tr("am") : tr("pm");
+        pm = (h < 12) ? tr("am") :
+                        tr("pm");
     }
 
     hh = (h == 12 || h == 0) ? 12 : h % 12;
@@ -135,7 +175,7 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
     if (func && check_subst_args(func, 1)) {
         snprintf(s, sizeof(s), "subst_ampm(%d)", ch);
         expr = (char const *) s;
-        r = EvalExpr(&expr, &v, NULL);
+        r = EvalExprRunDisabled(&expr, &v, NULL);
         if (r == OK) {
             if (!DoCoerce(STR_TYPE, &v)) {
                 snprintf(mycpm, sizeof(mycpm), "%s", v.v.str);
@@ -149,7 +189,8 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
         }
     }
     if (r != OK) {
-        cpm = (h < 12) ? tr("am") : tr("pm");
+        cpm = (h < 12) ? tr("am") :
+                         tr("pm");
     }
     chh = (ch == 0 || ch == 12) ? 12 : ch % 12;
 
@@ -157,7 +198,7 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
     if (func && check_subst_args(func, 1)) {
         snprintf(s, sizeof(s), "subst_ordinal(%d)", d);
         expr = (char const *) s;
-        r = EvalExpr(&expr, &v, NULL);
+        r = EvalExprRunDisabled(&expr, &v, NULL);
         if (r == OK) {
             if (!DoCoerce(STR_TYPE, &v)) {
                 snprintf(myplu, sizeof(myplu), "%s", v.v.str);
@@ -311,7 +352,9 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
             }
             func = FindUserFunc(s);
             if (!func) {
-                Wprint(tr("No substition function `%s' defined"), s);
+                if (warning_level("05.00.03")) {
+                    Wprint(tr("No substition function `%s' defined"), s);
+                }
                 continue;
             }
 
@@ -321,7 +364,7 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
             snprintf(ss, sizeof(s) - (ss-s), "(%d,'%04d-%02d-%02d',%02d:%02d)",
                      altmode ? 1 : 0, y, m+1, d, h, min);
             expr = (char const *) s;
-            r = EvalExpr(&expr, &v, NULL);
+            r = EvalExprRunDisabled(&expr, &v, NULL);
             if (r == OK) {
                 if (!DoCoerce(STR_TYPE, &v)) {
                     if (DBufPuts(dbuf, v.v.str) != OK) {
@@ -334,13 +377,17 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
             continue;
         }
         done = 0;
-        snprintf(uf, sizeof(uf), "subst_%c", tolower(c));
-        func = FindUserFunc(uf);
+        substname = get_function_override(c, 0);
+        if (substname) {
+            func = FindUserFunc(substname);
+        } else {
+            func = NULL;
+        }
         if (func && check_subst_args(func, 3)) {
-            snprintf(s, sizeof(s), "subst_%c(%d,'%04d-%02d-%02d',%02d:%02d)",
-                     tolower(c), altmode ? 1 : 0, y, m+1, d, h, min);
+            snprintf(s, sizeof(s), "%s(%d,'%04d-%02d-%02d',%02d:%02d)",
+                     substname, altmode ? 1 : 0, y, m+1, d, h, min);
             expr = (char const *) s;
-            r = EvalExpr(&expr, &v, NULL);
+            r = EvalExprRunDisabled(&expr, &v, NULL);
             if (r == OK) {
                 if (v.type != INT_TYPE || v.v.val != 0) {
                     if (!DoCoerce(STR_TYPE, &v)) {
@@ -358,7 +405,7 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
             }
         }
 
-        if (diff <= 1) {
+        if (abs(diff) <= 1) {
             switch(UPPER(c)) {
             case 'A':
             case 'B':
@@ -373,7 +420,9 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
             case 'L':
             case 'U':
             case 'V':
-                snprintf(s, sizeof(s), "%s", (diff ? tr("tomorrow") : tr("today")));
+                snprintf(s, sizeof(s), "%s", (diff == 1 ? tr("tomorrow") :
+                                              diff == -1 ? tr("yesterday") :
+                                              tr("today")));
                 SHIP_OUT(s);
                 done = 1;
                 break;
@@ -384,13 +433,17 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
 
 
         if (!done) {
-            snprintf(uf, sizeof(uf), "subst_%cx", tolower(c));
-            func = FindUserFunc(uf);
+            substname = get_function_override(c, 1);
+            if (substname) {
+                func = FindUserFunc(substname);
+            } else {
+                func = NULL;
+            }
             if (func && check_subst_args(func, 3)) {
-                snprintf(s, sizeof(s), "subst_%cx(%d,'%04d-%02d-%02d',%02d:%02d)",
-                         tolower(c), altmode ? 1 : 0, y, m+1, d, h, min);
+                snprintf(s, sizeof(s), "%s(%d,'%04d-%02d-%02d',%02d:%02d)",
+                         substname, altmode ? 1 : 0, y, m+1, d, h, min);
                 expr = (char const *) s;
-                r = EvalExpr(&expr, &v, NULL);
+                r = EvalExprRunDisabled(&expr, &v, NULL);
                 if (r == OK) {
                     if (v.type != INT_TYPE || v.v.val != 0) {
                         if (!DoCoerce(STR_TYPE, &v)) {
@@ -407,9 +460,11 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
                     Eprint("%s", GetErr(r));
                 }
             }
-            if (origtime == NO_TIME) {
-                if ((c >= '0' && c <= '9') || (c == '!')) {
-                    Wprint(tr("`%%%c' substitution sequence should not be used without an AT clause"), c);
+            if (warning_level("05.03.04")) {
+                if (origtime == NO_TIME) {
+                    if ((c >= '0' && c <= '9')) {
+                        Wprint(tr("`%%%c' substitution sequence should not be used without an AT clause"), c);
+                    }
                 }
             }
 
@@ -426,7 +481,11 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
                 break;
 
             case 'B':
-                snprintf(s, sizeof(s), "in %d days' time", diff);
+                if (diff > 0) {
+                    snprintf(s, sizeof(s), "in %d days' time", diff);
+                } else {
+                    snprintf(s, sizeof(s), "%d days ago", -diff);
+                }
                 SHIP_OUT(s);
                 break;
 
@@ -605,6 +664,12 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
                 SHIP_OUT(s);
                 break;
 
+            case ':':
+                if (t->is_todo && t->complete_through != NO_DATE && t->complete_through >= dse) {
+                    snprintf(s, sizeof(s), " (%s)", tr("done"));
+                    SHIP_OUT(s);
+                }
+                break;
             case '1':
                 if (tdiff == 0)
                     snprintf(s, sizeof(s), "%s", tr("now"));
@@ -614,7 +679,8 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
                     snprintf(s, sizeof(s), "%d %s%s %s", hdiff, tr("hour"), hplu, when);
                 else
                     snprintf(s, sizeof(s), "%d %s%s %s %d %s%s %s", hdiff, tr("hour"), hplu,
-                             tr("and"), mdiff, tr("minute"), mplu, when);
+                             tr("and"), mdiff,
+                             tr("minute"), mplu, when);
                 SHIP_OUT(s);
                 break;
 
@@ -672,7 +738,26 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int
                 break;
 
             case '!':
-                snprintf(s, sizeof(s), "%s", (tdiff >= 0 ? tr("is") : tr("was")));
+            case '?':
+                if (c == '!') {
+                    is = tr("is");
+                    was = tr("was");
+                } else {
+                    is = tr("are");
+                    was = tr("were");
+                }
+                if (altmode) {
+                    bangdiff = rdiff;
+                } else {
+                    bangdiff = diff;
+                }
+                if (bangdiff > 0) {
+                    snprintf(s, sizeof(s), "%s", is);
+                } else if (bangdiff < 0) {
+                    snprintf(s, sizeof(s), "%s", was);
+                } else {
+                    snprintf(s, sizeof(s), "%s", (tdiff >= 0 ? is : was));
+                }
                 SHIP_OUT(s);
                 break;
 
