@@ -134,6 +134,11 @@
 #define E_MAX_OVERDUE_WITHOUT_TODO 110
 #define E_TZ_SPECIFIED_TWICE 111
 #define E_TZ_NO_AT          112
+#define E_NO_MB             113
+#define E_BAD_MB_SEQ        114
+#define E_EXPR_NODES_EXCEEDED 115
+#define E_EXPECTING_EOXPR   116
+#define E_EXPECTING_ATOM    117
 
 #ifdef MK_GLOBALS
 #undef EXTERN
@@ -265,6 +270,11 @@ EXTERN char *ErrMsg[]
 /* E_MAX_OVERDUE_WITHOUT_TODO */ "MAX-OVERDUE specified without TODO",
 /* E_TZ_SPECIFIED_TWICE */ "TZ specified twice",
 /* E_TZ_NO_AT */           "TZ specified for non-timed reminder",
+/* E_NO_MB */              "C library does not support multibyte characters",
+/* E_BAD_MB_SEQ */         "Invalid multibyte sequence",
+/* E_EXPR_NODES_EXCEEDED */ "Maximum expression complexity exceeded",
+/* E_EXPECTING_EOXPR */    "Expecting operator or end-of-expression",
+/* E_EXPECTING_ATOM */     "Expecting constant, variable, function call or (expression)",
 }
 #endif /* MK_GLOBALS */
 ;
