@@ -99,8 +99,8 @@ static size_t bucket_choices[] = {
 int
 hash_table_init(hash_table *t,
                 size_t link_offset,
-                unsigned int (*hashfunc)(void *x),
-                int (*compare)(void *a, void *b))
+                unsigned int (*hashfunc)(void const *x),
+                int (*compare)(void const *a, void const *b))
 {
     t->bucket_choice_index = 0;
     t->num_entries         = 0;
@@ -141,7 +141,7 @@ hash_table_free(hash_table *t)
  * \return The number of items in the hash table
  */
 size_t
-hash_table_num_entries(hash_table *t)
+hash_table_num_entries(hash_table const *t)
 {
     return t->num_entries;
 }
@@ -154,7 +154,7 @@ hash_table_num_entries(hash_table *t)
  * \return The number of buckets in the hash table
  */
 size_t
-hash_table_num_buckets(hash_table *t)
+hash_table_num_buckets(hash_table const *t)
 {
     if (t->bucket_choice_index >= NUM_BUCKET_CHOICES) {
         return 0;
@@ -321,7 +321,7 @@ hash_table_find(hash_table *t, void *candidate)
  *
  * \return 0 on success, -1 on failure
  */
-int
+static int
 hash_table_delete_helper(hash_table *t, void *item, int resize_ok)
 {
     if (!item) {
