@@ -36,8 +36,10 @@
 #endif
 
 #ifdef HAVE_SYS_TERMIOS_H
+#ifdef __sun
 #include <sys/termios.h>
 #endif
+#endif
 
 
 #include "types.h"
@@ -517,6 +519,11 @@ void InitRemind(int argc, char const *argv[])
                         arg++;
                         continue;
                     }
+                    if (*arg == 'z' || *arg == 'Z') {
+                        LinksInTerminal = 1;
+                        arg++;
+                        continue;
+                    }
                     break;
                 }
                 if (weeks) {
