@@ -1307,7 +1307,7 @@ int DoIfTrig(ParsePtr p)
             push_if(0, 0);
         } else {
             if (dse >= 0) {
-                dse = AdjustTriggerForTimeZone(&trig, dse, &tim);
+                dse = AdjustTriggerForTimeZone(&trig, dse, &tim, 1);
             }
             if (ShouldTriggerReminder(&trig, &tim, dse, &err)) {
                 push_if(1, 0);
