@@ -300,7 +300,7 @@ int system_to_stderr(char const *cmd);
 int system1(char const *cmd);
 int tz_set_tz (char const *tz);
 int tz_convert(int year, int month, int day, int hour, int minute, char const *src_tz, char const *tgt_tz, struct tm *tm);
-int AdjustTriggerForTimeZone(Trigger *trig, int dse, TimeTrig *tim);
+int AdjustTriggerForTimeZone(Trigger *trig, int dse, TimeTrig *tim, int debug_ok);
 void EnterTimezone(char const *tz);
 void ExitTimezone(char const *tz);
 int warning_level(char const *which);
