@@ -190,7 +190,7 @@ maybe_close(int fd)
 {
     int new_fd;
     /* Don't close descriptors connected to a TTY, except for stdin */
-    if (fd && isatty(fd)) return;
+    if (fd != STDIN_FILENO && isatty(fd)) return;
 
     (void) close(fd);
     if (fd != STDIN_FILENO) {
@@ -280,6 +280,8 @@ void HandleQueuedReminders(void)
         maybe_close(STDIN_FILENO);
         maybe_close(STDOUT_FILENO);
         maybe_close(STDERR_FILENO);
+    } else if (!Daemon) {
+        maybe_close(STDIN_FILENO);
     }
 
     /* If we're a daemon, get the mod time of initial file */
@@ -310,7 +312,9 @@ void HandleQueuedReminders(void)
     }
 
 #ifdef USE_INOTIFY
-    watch_fd = setup_inotify_watch();
+    if (IsServerMode()) {
+        watch_fd = setup_inotify_watch();
+    }
 #endif
     /* Sit in a loop, issuing reminders when necessary */
     while(1) {
@@ -395,7 +399,6 @@ void HandleQueuedReminders(void)
              (MaxLateMinutes == 0 || SystemTime(1) - (q->tt.nexttime * 60) <= 60 * MaxLateMinutes))) {
             /* Trigger the reminder */
             CreateParser(q->text, &p);
-            RunDisabled = q->RunDisabled;
             if (IsServerMode() && q->typ != RUN_TYPE) {
                 if (DaemonJSON) {
                     printf("{\"response\":\"reminder\",");
@@ -436,7 +439,7 @@ void HandleQueuedReminders(void)
             if (DaemonJSON) {
                 DynamicBuffer out;
                 DBufInit(&out);
-                (void) TriggerReminder(&p, &tcopy, &q->tt, DSEToday, 1, &out);
+                (void) TriggerReminder(&p, &tcopy, &q->tt, DSEToday, 1, &out, NULL, NULL, NULL);
                 if (q->typ != RUN_TYPE) {
                     printf("\"body\":\"");
                     chomp(&out);
@@ -445,7 +448,7 @@ void HandleQueuedReminders(void)
                 }
                 DBufFree(&out);
             } else {
-                (void) TriggerReminder(&p, &tcopy, &q->tt, DSEToday, 1, NULL);
+                (void) TriggerReminder(&p, &tcopy, &q->tt, DSEToday, 1, NULL, NULL, NULL, NULL);
             }
             if (IsServerMode() && !DaemonJSON && q->typ != RUN_TYPE) {
                 printf("NOTE endreminder\n");
@@ -640,13 +643,15 @@ static int CalculateNextTimeUsingSched(QueuedRem *q)
         return NO_TIME;
     }
 
-    RunDisabled = q->RunDisabled;  /* Don't want weird scheduling functions
-                                     to be a security hole!                */
     while(1) {
         char exprBuf[VAR_NAME_LEN+32];
         snprintf(exprBuf, sizeof(exprBuf), "%s(%d)", q->sched, q->ntrig);
         s = exprBuf;
-        r = EvalExpr(&s, &v, NULL);
+        if (q->RunDisabled) {
+            r = EvalExprRunDisabled(&s, &v, NULL);
+        } else {
+            r = EvalExpr(&s, &v, NULL);
+        }
         if (r) {
             q->sched[0] = 0;
             return NO_TIME;
@@ -704,7 +709,7 @@ json_queue(QueuedRem const *q)
         }
         done = 1;
         printf("{");
-        WriteJSONTrigger(&(q->t), 1, DSEToday);
+        WriteJSONTrigger(&(q->t), 1);
         WriteJSONTimeTrigger(&(q->tt));
         if (TestMode) {
             snprintf(idbuf, sizeof(idbuf), "42424242");
