@@ -26,6 +26,8 @@
 #include "globals.h"
 #include "protos.h"
 #include "err.h"
+#include "version.h"
+
 #define UPPER(c) (islower(c) ? toupper(c) : c)
 
 #define VARIABLE GetErr(E_VAR)
@@ -189,6 +191,52 @@ static int latitude_func(int do_set, Value *val)
     return latitude_longitude_func(do_set, val, &Latitude, -90.0, 90.0);
 }
 
+static int warning_level_func(int do_set, Value *val)
+{
+    if (do_set) {
+        if (val->type != STR_TYPE) return E_BAD_TYPE;
+        if (!val->v.str || ! (*val->v.str)) {
+            if (WarningLevel) free((void *) WarningLevel);
+            WarningLevel = NULL;
+            return OK;
+        }
+        if (strlen(val->v.str) != 8) {
+            return E_BAD_NUMBER;
+        }
+        /* Must match regex: ^\d\d\.\d\d\.\d\d$ */
+        if (!isdigit(val->v.str[0]) ||
+            !isdigit(val->v.str[1]) ||
+            val->v.str[2] != '.'    ||
+            !isdigit(val->v.str[3]) ||
+            !isdigit(val->v.str[4]) ||
+            val->v.str[5] != '.'    ||
+            !isdigit(val->v.str[6]) ||
+            !isdigit(val->v.str[7])) {
+            return E_BAD_NUMBER;
+        }
+
+        if (WarningLevel) free((void *) WarningLevel);
+        /* If it's the same as VERSION, just leave it as NULL */
+        if (!strcmp(val->v.str, VERSION)) {
+            WarningLevel = NULL;
+        } else {
+            WarningLevel = StrDup(val->v.str);
+            if (!WarningLevel) return E_NO_MEM;
+        }
+        return OK;
+    }
+    if (!WarningLevel) {
+        val->v.str = StrDup(VERSION);
+    } else {
+        val->v.str = StrDup(WarningLevel);
+    }
+    if (!val->v.str) {
+        return E_NO_MEM;
+    }
+    val->type = STR_TYPE;
+    return OK;
+}
+
 static int oncefile_func(int do_set, Value *val)
 {
     if (do_set) {
@@ -761,6 +809,7 @@ int DoDump(ParsePtr p)
     int dump_constness = 0;
 
     if (PurgeMode) return OK;
+    if (JSONMode) return OK;
 
     DBufInit(&buf);
     r = ParseToken(p, &buf);
@@ -785,9 +834,14 @@ int DoDump(ParsePtr p)
             DumpSysVarByName(DBufValue(&buf)+1);
         } else {
             v = FindVar(DBufValue(&buf), 0);
-            DBufValue(&buf)[VAR_NAME_LEN] = 0;
-            if (!v) fprintf(ErrFp, "%s  %s\n",
+            if (!v) {
+                if (DBufLen(&buf) > VAR_NAME_LEN) {
+                    /* Truncate over-long variable name */
+                    DBufValue(&buf)[VAR_NAME_LEN] = 0;
+                }
+                fprintf(ErrFp, "%s  %s\n",
                             DBufValue(&buf), UNDEF);
+            }
             else {
                 fprintf(ErrFp, "%s  ", v->name);
                 PrintValue(&(v->v), ErrFp);
@@ -992,6 +1046,7 @@ static SysVar SysVarArr[] = {
     {"FormWidth",      1,  INT_TYPE,     &FormWidth,           20,     500 },
     {"Friday",         1,  TRANS_TYPE,   "Friday",             0,      0 },
     {"Fromnow",        1,  TRANS_TYPE,   "from now",           0,      0 },
+    {"HideCompletedTodos", 0, INT_TYPE,  &HideCompletedTodos,  0,      0 },
     {"Hour",           1,  TRANS_TYPE,   "hour",               0,      0 },
     {"Hplu",           1,  STR_TYPE,     &DynamicHplu,         0,      0 },
     {"HushMode",       0,  INT_TYPE,     &Hush,                0,      0 },
@@ -1001,6 +1056,7 @@ static SysVar SysVarArr[] = {
     {"IntMin",         0,  INT_TYPE,     &IntMin,              0,      0 },
     {"Is",             1,  TRANS_TYPE,   "is",                 0,      0 },
     {"January",        1,  TRANS_TYPE,   "January",            0,      0 },
+    {"JSONMode",       0,  INT_TYPE,     &JSONMode,            0,      0 },
     {"July",           1,  TRANS_TYPE,   "July",               0,      0 },
     {"June",           1,  TRANS_TYPE,   "June",               0,      0 },
     {"LatDeg",         1,  SPECIAL_TYPE, latdeg_func,          0,      0 },
@@ -1058,6 +1114,7 @@ static SysVar SysVarArr[] = {
     {"TimetIs64bit",   0,  SPECIAL_TYPE, timet_is_64_func,     0,      0 },
     {"Tm",             0,  SPECIAL_TYPE, trig_mon_func,        0,      0 },
     {"Today",          1,  TRANS_TYPE,   "today",              0,      0 },
+    {"TodoFilter",     0,  INT_TYPE,     &TodoFilter,          0,      0 },
     {"Tomorrow",       1,  TRANS_TYPE,   "tomorrow",           0,      0 },
     {"Tt",             0,  SPECIAL_TYPE, trig_time_func,       0,      0 },
     {"Tu",             0,  SPECIAL_TYPE, trig_until_func,      0,      0 },
@@ -1074,6 +1131,7 @@ static SysVar SysVarArr[] = {
     {"UseVTColors",    0,  INT_TYPE,     &UseVTColors,         0,      0 },
     {"Uw",             0,  SPECIAL_TYPE, today_wday_func,      0,      0 },
     {"Uy",             0,  SPECIAL_TYPE, today_year_func,      0,      0 },
+    {"WarningLevel",   1,  SPECIAL_TYPE, warning_level_func,   0,      0 },
     {"Was",            1,  TRANS_TYPE,   "was",                0,      0 },
     {"Wednesday",      1,  TRANS_TYPE,   "Wednesday",          0,      0 }
 };
